"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_d3_utils_1 = require("react-d3-utils");
const bboxContext_1 = require("../../contexts/bboxContext");
const Ticks_1 = require("./Ticks");
const VerticalAxisGridLines_1 = __importDefault(require("./VerticalAxisGridLines"));
const VerticalAxisLabel_1 = __importDefault(require("./VerticalAxisLabel"));
const VerticalAxisLine_1 = __importDefault(require("./VerticalAxisLine"));
function VerticalAxis(props) {
    const { primaryTickStyle, primaryTickLength, tickPosition, hiddenTicks, primaryGridLineStyle, lineStyle, hiddenLine, hidden, plotWidth, plotHeight, displayPrimaryGridLines, label, labelStyle, axisRef, primaryTicks, position, tickLabelStyle, innerOffset, } = props;
    const isRight = position === 'right';
    const textOffset = 3;
    const transform = isRight ? `translate(${plotWidth}, 0)` : undefined;
    const ticks = (0, react_d3_utils_1.useBBoxObserver)();
    function getTickPosition(value) {
        const { x1, x2, textPosition } = getTickX();
        return {
            line: {
                y1: value,
                y2: value,
                x1: x1,
                x2: x2,
            },
            text: { y1: value, x1: isRight ? textPosition : -textPosition },
        };
    }
    function getTickX() {
        const x = isRight ? primaryTickLength : -primaryTickLength;
        switch (tickPosition) {
            case 'center':
                return {
                    x1: x / 2,
                    x2: -x / 2,
                    textPosition: textOffset + primaryTickLength / 2,
                };
            case 'inner':
                return {
                    x1: 0,
                    x2: -x,
                    textPosition: textOffset,
                };
            case 'outer':
                return {
                    x1: 0,
                    x2: x,
                    textPosition: textOffset + primaryTickLength,
                };
            default:
                return {
                    x1: 0,
                    x2: 0,
                    textPosition: 3,
                };
        }
    }
    const gridLinesElement = displayPrimaryGridLines ? ((0, jsx_runtime_1.jsx)(VerticalAxisGridLines_1.default, { position: position, plotWidth: plotWidth, primaryTicks: primaryTicks, style: primaryGridLineStyle }, void 0)) : null;
    const primaryTicksElement = !hidden && !hiddenTicks ? ((0, jsx_runtime_1.jsx)(Ticks_1.Ticks, { anchor: isRight ? 'start' : 'end', primaryTicks: primaryTicks, getPositions: getTickPosition, labelStyle: tickLabelStyle, style: primaryTickStyle }, void 0)) : null;
    const axisLineElement = !hidden && !hiddenLine ? ((0, jsx_runtime_1.jsx)(VerticalAxisLine_1.default, { style: lineStyle, plotHeight: plotHeight }, void 0)) : null;
    const labelElement = !hidden && label ? ((0, jsx_runtime_1.jsx)(VerticalAxisLabel_1.default, { plotHeight: plotHeight, label: label, labelStyle: labelStyle, horizontalAlign: isRight ? 'start' : 'end' }, void 0)) : null;
    const bboxRef = (0, react_1.useContext)(bboxContext_1.bboxContext);
    return ((0, jsx_runtime_1.jsxs)("g", { transform: transform, children: [gridLinesElement, (0, jsx_runtime_1.jsxs)("g", { ref: bboxRef, children: [(0, jsx_runtime_1.jsx)("g", { ref: ticks.ref, children: primaryTicksElement }, void 0), (0, jsx_runtime_1.jsx)("g", { ref: axisRef, children: axisLineElement }, void 0), (0, jsx_runtime_1.jsx)("g", { transform: `translate(${(ticks.width - innerOffset) * (isRight ? 1 : -1)}, 0)`, children: labelElement }, void 0)] }, void 0)] }, void 0));
}
exports.default = VerticalAxis;
